@@ -1,10 +1,6 @@
-import email
-from genericpath import isfile
 import os
 
-
 email_list = []
-
 def get_emails(dir):
     for files in os.listdir(dir):
         f= os.path.join(dir, files)
